@@ -170,14 +170,23 @@ class LibMarkdown(object):
                     argv[0].split("||")[0].replace("_","").lower() +")|"
 
         for i in argv[1:]:
-            data += str(i) + "|"
+            if len(i) != 0:
+                data += str(i) + "|"
+            else:
+                data += "&nbsp;" + "|"
         data = data + "\n"
         return data
 
     def md_create_body_line2(self, argv):
         data = '|'
         for i in argv:
-            data += str(i) + "|"
+            if len(i) != 0:
+                msg = i.replace('；',';')
+                msg = msg.replace('。',';')
+                msg = '。<br>'.join(msg.strip(';').split(';'))
+                data += str(msg) + "|"
+            else:
+                data += "&nbsp;" + "|"
         data = data + "\n"
         return data
 
