@@ -14,7 +14,7 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.2.0'
+__version__ = 'v1.2.5'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook):
@@ -406,7 +406,8 @@ class TranslateJson(object):
         svg_name = name + ".svg"
         with open(svg_name, "w") as fd:
             fd.write(svg_data)
-        register_data = "![](" + svg_name + ")\n<br>"
+        #register_data = "![](" + svg_name + ")\n<br>"
+        register_data = "![](" + svg_name + ")\n"
 
         line = lm.md_create_title_line(['位域','变量名', '属性', '默认值', '描述'])
         register_data += "\n\n" + line
@@ -420,7 +421,7 @@ class TranslateJson(object):
                 register_data += line
             else:
                 line = self.add_description_table(lm, [f['range'], f['name'], \
-                        ' ',' ',' '])
+                        '','',''])
                 register_data += line
     
         #table_title = 'Register:' + name + ' ('  + addr + ')'
@@ -433,7 +434,8 @@ class TranslateJson(object):
             self.data += register_data +'\n'
         if self.output_gitbook:
             os.system("mv " + svg_name + " " + self.gitbookpath)
-            register_data += '\n<br>\n'
+            #register_data += '\n<br>\n'
+            register_data += '\n'
             file_path = os.path.join(self.gitbookpath, name + '.md')
             self.reg_rst += '   ' + name + '.md\n'
             with open(file_path, 'w') as fd:
@@ -515,6 +517,8 @@ class TranslateJson(object):
                             dpath = self.js_dpath[i]
                             fd.write('  * [' + name + ']('+ name + '.md)\n')
                             self.create_md3(self.js_dpath[i], lm)
+                    self.relist(self.all_reg_list)
+                    self.create_all_reg_data(lm)
                     with open(os.path.join(self.gitbookpath, 'all_register.md'), 'w') as fc:
                         fc.write("## 寄存器列表\n\n" + self.all_reg_data)
                 print("\n\tcreate " + self.gitbookpath +" success") 
